@@ -538,16 +538,13 @@ Arnolfini.carouselFix = function ()
 	$("#MainContent").css("background-image", "none");
 }
 
-
-Arnolfini.trackEcommerce = function ()
-{
-	
-}
-
-Arnolfini.sendPaypalTrack = function (title, price)
+Arnolfini.trackEcommerce = function (title, price)
 {
+	var d = new Date();
+	var timestamp = d.getDate().toString() + "-" + (d.getMonth() + 1) +"-"+ d.getFullYear().toString() +"-"+ d.getHours().toString() +":"+ d.getMinutes().toString();
+	console.log("Tracking transaction "+encodeURIComponent(title) + timestamp +" with price: " + price);
 	_gaq.push(['_addTrans',
-	   encodeURIComponent(title),           // transaction ID - required
+	   encodeURIComponent(encodeURIComponent(title) + "-" + timestamp),           // transaction ID - required
 	   'Arnolfini', // affiliation or store name
 	   price.toString(),          // total - required
 	   '',           // tax
@@ -613,10 +610,17 @@ $(document).ready(function() {
 	
 	//iPad Viewport
 	if( navigator.userAgent.match(/iPad/i) == null ){  
-		viewport = document.querySelector("meta[name=viewport]");  
-		viewport.setAttribute('content', "width=777, initial-scale=0.3");  
+		viewport = document.querySelector("meta[name=viewport]");
+		
+		if (navigator.userAgent.match(/Android/i) != null)
+		{
+			viewport.setAttribute('content', "width=777, initial-scale=0.3");
+		}
+		else
+		{
+			viewport.setAttribute('content', "width=777, initial-scale=0.5");
+		}
+		
 	}
-	
-	Arnolfini.trackEcommerce();
 });
 
