@@ -98,7 +98,7 @@ class CommonBrowserView(BrowserView):
         
     def addPaypalButton(self, label, name, price):
         return """
-            <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
+            <form action="https://www.paypal.com/cgi-bin/webscr" method="post" onSubmit="return Arnolfini.trackEcommerce('%(name)s', '%(price).2f')">
                 <input name="business" type="hidden" value="arnolfini@intk.com" />
                 <input name="amount" type="hidden" value="%(price).2f" />
                 <input name="item_name" type="hidden" value="%(name)s" />
